.. _recipe_asr.setinfo:

asr.setinfo
===========


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.setinfo`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.setinfo.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.setinfo

or as a python module

.. code-block:: console

   $ python -m asr.setinfo

Detailed description
--------------------
Manually set key-value-pairs for material.

Steps
-----


asr.setinfo
^^^^^^^^^^^
.. autofunction:: asr.setinfo.main
   